@@ -80,16 +80,14 @@ Q_SIGNALS:
      */
     void arrowDownKeyPressed();
 
-private Q_SLOTS:
-    void resetTimer();
-    void delayedTextChanged();
-
 protected:
     void keyPressEvent(QKeyEvent *) override;
 
 private:
-    QLineEdit *mEdit;
-    QTimer *mTimer;
+    void resetTimer();
+    void delayedTextChanged();
+    QLineEdit *mEdit = nullptr;
+    QTimer *mTimer = nullptr;
 };
 
 #endif
